@@ -21,7 +21,6 @@ from . import terminal_attributes as term
 from . import voigt
 
 plt.rcParams['lines.linewidth'] = 1.0
-plt.rcParams['font.family'] = 'Arial'
 
 
 valid_kwargs = list(Line2D.properties(Line2D([0], [0])).keys())
@@ -467,7 +466,7 @@ def plot_all_lines(dataset, plot_fit=True, rebin=1, fontsize=12, xmin=None,
         fig.set_tight_layout(True)
         if filename:
             pdf.close()
-            print(" - Saved the fitted lines to PDF file: %s" % filename)
+            print("\n  Output saved to PDF file:  " + filename)
 
         if show:
             plt.show()
@@ -895,8 +894,8 @@ def plot_single_line(dataset, line_tag, index=0, plot_fit=False,
             if norm_resid:
                 cax.axhline(3, ls=':', color='crimson', lw=0.5)
                 cax.axhline(-3, ls=':', color='crimson', lw=0.5)
-                res_min = -5
-                res_max = 5
+                res_min = 4
+                res_max = -4
             else:
                 if xunit == 'wl':
                     cax.errorbar(x, resid, err, ls='', color='gray', lw=1.)
@@ -906,8 +905,8 @@ def plot_single_line(dataset, line_tag, index=0, plot_fit=False,
                     cax.errorbar(vel, resid, err, ls='', color='gray', lw=1.)
                     cax.plot(vel, 3*err, ls=':', color='crimson', lw=1.)
                     cax.plot(vel, -3*err, ls=':', color='crimson', lw=1.)
-                res_min = -np.nanmean(5*err)
-                res_max = np.nanmean(5*err)
+                res_min = np.nanmax(4*err)
+                res_max = np.nanmin(-4*err)
 
             cax.axhline(0., ls='--', color='0.7', lw=0.7)
             cax.tick_params(labelbottom=False)
@@ -971,7 +970,8 @@ def plot_single_line(dataset, line_tag, index=0, plot_fit=False,
     return (ax, lines_in_view)
 
 
-def plot_residual(dataset, line_tag, index=0, rebin=1, xmin=None, xmax=None, axis=None):
+def plot_residual(dataset, line_tag, index=0, rebin=1,
+                  xmin=None, xmax=None, axis=None):
     """
     Plot residuals for the best-fit to a given absorption line.
 
@@ -1402,8 +1402,9 @@ def plot_H2(dataset, n_rows=None, xmin=None, xmax=None,
     Jmax = [item[1] for item in dataset.molecules[molecule]]
     molecular_lines = [line for line in dataset.lines.values()
                        if molecule in line.tag]
-    profile = evaluate_profile(wl_profile, dataset.best_fit,
-                               molecular_lines, kernel, z_sys=dataset.redshift, sampling=10)
+    profile = evaluate_profile(wl_profile, dataset.best_fit, dataset.redshift,
+                               molecular_lines, dataset.components, kernel,
+                               sampling=3)
     if not xmin:
         xmin = min(min_wl)
     if not xmax:
@@ -1438,48 +1439,6 @@ def plot_H2(dataset, n_rows=None, xmin=None, xmax=None,
     plt.show()
 
 
-def plot_limit(dataset, line, ref_line, vel_ref, tau, vmin, vmax, use_data, filename=None, EW=None):
-    fig, axes = plt.subplots(nrows=2, ncols=1)
-    # -- Plot data for the target line:
-    regs_of_line = dataset.find_line(line.tag)
-    reg = regs_of_line[0]
-    vel = reg.get_velocity(dataset.redshift, line.tag)
-    noise = np.nanmedian(reg.err)
-    axes[0].plot(vel, reg.flux, color='k', lw=1.0, drawstyle='steps-mid')
-    axes[0].errorbar(vel, reg.flux, reg.err, ecolor='0.3', ls='', alpha=0.5, elinewidth=0.8)
-    axes[0].set_xlim(vel.min(), vel.max())
-    axes[0].set_ylim(1.-6*noise, 1.+6*noise)
-    axes[0].axhline(1., ls=':', color='k', lw=1., alpha=0.5)
-    axes[0].axvline(vmin, ls='--', color='r', alpha=0.8)
-    axes[0].axvline(vmax, ls='--', color='r', alpha=0.8)
-    if EW is not None:
-        Wlim = EW.W_err * EW.sigma
-        txt = "%.2e" % Wlim
-        num, exp = txt.split('e')
-        Wlim_str = "%s x 10$^{%i}$" % (num, int(exp))
-        Nlim = EW.logN_limit
-        text_label = 'W(%s) < %s Å   log(N/cm$^{-2}$) < %.2f' % (line.tag, Wlim_str, Nlim)
-        axes[0].set_title(text_label)
-    axes[0].set_ylabel("Normalized Flux")
-
-    # -- Plot apparent optical depth for reference line:
-    if use_data:
-        axes[1].plot(vel_ref, tau, color='k', lw=1.0, drawstyle='steps-mid', label='Observed AOD (%s)' % ref_line.tag)
-    else:
-        axes[1].plot(vel_ref, tau, color='RoyalBlue', lw=1.5, label='Model AOD (%s)' % ref_line.tag)
-    axes[1].axvline(vmin, ls='--', color='r', alpha=0.8)
-    axes[1].axvline(vmax, ls='--', color='r', alpha=0.8)
-    axes[1].set_xlim(vel.min(), vel.max())
-    axes[1].set_ylabel("Apparent Optical Depth (AOD)")
-    axes[1].set_xlabel("Rel. Velocity  [km s$^{-1}$]")
-    axes[1].legend()
-    fig.tight_layout()
-    if filename:
-        plt.savefig(filename)
-    else:
-        plt.show()
-
-
 # ===================================================================================
 #
 #   Text output functions:
@@ -1521,9 +1480,7 @@ def print_results(dataset, params, elements='all', velocity=True, systemic=0):
     else:
         z_sys = dataset.redshift
 
-    print("\n----------------------")
-    print("  Best fit parameters:")
-    print("----------------------\n")
+    print("\n  Best fit parameters\n")
     print("\t\t\t\tb\t\t\tlog(N)")
     if elements == 'all':
         for ion in sorted(dataset.components.keys()):
@@ -1562,15 +1519,15 @@ def print_results(dataset, params, elements='all', velocity=True, systemic=0):
                 if velocity:
                     z_std = z_err/(z_sys+1)*299792.458
                     z_val = (z-z_sys)/(z_sys+1)*299792.458
-                    z_format = "v = %+5.1f ± %.1f      "
+                    z_format = "v = %5.1f +/- %.1f\t"
                 else:
                     z_std = z_err
                     z_val = z
-                    z_format = "z = %+.6f ± %.6f"
+                    z_format = "z = %.6f +/- %.6f"
 
-                output_string = z_format % (z_val, z_std) + "      "
-                output_string += "%6.2f ± %6.2f      " % (b, b_err)
-                output_string += "%7.3f ± %7.3f" % (logN, logN_err)
+                output_string = z_format % (z_val, z_std) + "\t"
+                output_string += "%6.2f +/- %6.2f\t" % (b, b_err)
+                output_string += "%.3f +/- %.3f" % (logN, logN_err)
 
                 print(output_string)
 
@@ -1597,39 +1554,26 @@ def print_results(dataset, params, elements='all', velocity=True, systemic=0):
                 logN_err = params['logN%i_%s' % (n, ion)].stderr
 
                 if velocity:
-                    z_std = z_err/(z_sys+1)*299792.458
-                    z_val = (z-z_sys)/(z_sys+1)*299792.458
-                    z_format = "v = %+5.1f ± %.1f      "
+                    z_val = (z-z_sys) / (z_sys+1) * 299792.458
+                    z_format = "v = %5.1f\t"
                 else:
-                    z_std = z_err
                     z_val = z
-                    z_format = "z = %+.6f ± %.6f"
+                    z_format = "z = %.6f"
 
-                output_string = z_format % (z_val, z_std) + "      "
-                output_string += "%6.2f ± %6.2f      " % (b, b_err)
-                output_string += "%.3f ± %.3f" % (logN, logN_err)
+                output_string = z_format % (z_val, z_std) + "\t"
+                output_string += "%6.2f +/- %6.2f\t" % (b, b_err)
+                output_string += "%.3f +/- %.3f" % (logN, logN_err)
 
                 print(output_string)
 
             print("")
 
-    for varname in dataset.static_variables.keys():
-        par = dataset.best_fit[varname]
-        err = par.stderr
-        if err is None:
-            err = 0.
-        output_string = "%s = %.3e ± %.3e" % (varname, par.value, err)
-        print(output_string)
-    print("")
-
 
 def print_cont_parameters(dataset):
     """ Print the Chebyshev coefficients of the continuum normalization."""
     if dataset.cheb_order >= 0:
         print("")
-        print("---------------------------------------------")
         print("  Chebyshev coefficients for fitting regions:")
-        print("---------------------------------------------\n")
         for reg_num, region in enumerate(dataset.regions):
             if not region.has_active_lines():
                 continue
@@ -1682,10 +1626,8 @@ def print_metallicity(dataset, params, logNHI, err=0.1):
 
     """
 
-    print("\n----------------")
-    print("  Metallicities:")
-    print("----------------\n")
-    print("  log(NHI) = %.3f ± %.3f\n" % (logNHI, err))
+    print("\n  Metallicities\n")
+    print("  log(NHI) = %.3f +/- %.3f\n" % (logNHI, err))
     logNHI = np.random.normal(logNHI, err, 10000)
     for ion in sorted(dataset.components.keys()):
         element = ion[:2] if ion[1].islower() else ion[0]
@@ -1711,22 +1653,20 @@ def print_metallicity(dataset, params, logNHI, err=0.1):
         metal_array = logN_tot - logNHI - (solar_abundance - 12.)
         metal = np.mean(metal_array)
         metal_err = np.std(metal_array)
-        print("  [%s/H] = %.3f ± %.3f" % (ion, metal, metal_err))
+        print("  [%s/H] = %.3f +/- %.3f" % (ion, metal, metal_err))
     print("")
 
 
-def print_total(dataset, verbose=True):
+def print_total(dataset):
     """
     Print the total column densities of all species. This will sum *all*
     the components of each ion. The uncertainty on the total column density
     is calculated using random resampling within the errors of each component.
     """
-    output = list()
+
     if isinstance(dataset.best_fit, dict):
         params = dataset.best_fit
-        output.append("-------------------------")
-        output.append("  Total Column Densities:")
-        output.append("-------------------------\n")
+        print("\n  Total Column Densities\n")
         for ion in sorted(dataset.components.keys()):
             # element = ion[:2] if ion[1].islower() else ion[0]
             logN = []
@@ -1739,23 +1679,18 @@ def print_total(dataset, verbose=True):
                         logN.append(params[par].value)
                         logN_err.append(params[par].stderr)
 
-            if len(logN) > 0:
-                ION = [np.random.normal(n, e, 10000) for n, e in zip(logN, logN_err)]
-                logsum = np.log10(np.sum(10**np.array(ION), 0))
-                l68, abundance, u68 = np.percentile(logsum, [16, 50, 84])
-                std_err = np.std(logsum)
-                output.append("  logN(%s) = %.2f ± %.2f" % (ion, abundance, std_err))
-            else:
-                output.append("  logN(%s) = ---" % ion)
+            ION = [np.random.normal(n, e, 10000)
+                   for n, e in zip(logN, logN_err)]
+            logsum = np.log10(np.sum(10**np.array(ION), 0))
+            l68, abundance, u68 = np.percentile(logsum, [16, 50, 84])
+            std_err = np.std(logsum)
 
-        if verbose:
-            print("")
-            print("\n".join(output))
-
-        return output
+            print("  logN(%s) = %.2f +/- %.2f" % (ion, abundance, std_err))
 
     else:
-        error_msg = """[ERROR] - The dataset has not yet been fitted. No parameters found!"""
+        error_msg = """
+        [ERROR] - The dataset has not yet been fitted. No parameters found!
+        """
         print(error_msg)
 
 
@@ -1832,10 +1767,10 @@ def sum_components(dataset, ion, components):
     return total_logN, total_logN_err
 
 
-def save_parameters_to_file(dataset, filename, path=''):
+def save_parameters_to_file(dataset, filename):
     """Save best-fit parameters to file."""
     header = "#comp   ion   redshift               b (km/s)       log(N/cm^-2)"
-    with open(path + filename, 'w') as output:
+    with open(filename, 'w') as output:
         output.write(header + "\n")
         for ion in sorted(dataset.components.keys()):
             for i in range(len(dataset.components[ion])):
@@ -1845,27 +1780,7 @@ def save_parameters_to_file(dataset, filename, path=''):
                 par_tuple = (i, ion, z.value, z.stderr,
                              b.value, b.stderr,
                              logN.value, logN.stderr)
-                line_fmt = "%3i  %7s  %+.6f %.6f    %6.2f %6.2f    %.3f %.3f"
-                output.write(line_fmt % par_tuple + "\n")
-            output.write("\n")
-
-        # Write total column densities:
-        logN_tot_str = print_total(dataset, verbose=False)
-        total_string = "\n".join(['#'+tmp for tmp in logN_tot_str])
-        output.write("\n\n" + total_string + "\n\n")
-
-        # Write a python script friendly version to copy into script:
-        output.write("# The commands below can be copied directly to the input file:\n")
-        z_sys = dataset.redshift
-        output.write("# z_sys : %.6f\n" % z_sys)
-        for ion in dataset.components.keys():
-            for i in range(len(dataset.components[ion])):
-                z = dataset.best_fit['z%i_%s' % (i, ion)]
-                logN = dataset.best_fit['logN%i_%s' % (i, ion)]
-                b = dataset.best_fit['b%i_%s' % (i, ion)]
-                vel_value = (z.value - z_sys) / (z_sys + 1) * 299792.458
-                par_tuple = (ion, vel_value, b.value, logN.value)
-                line_fmt = "# component %s  %+8.1f  %6.1f  %6.2f  velocity"
+                line_fmt = "%3i  %7s  %.6f %.6f    %6.2f %6.2f    %.3f %.3f"
                 output.write(line_fmt % par_tuple + "\n")
             output.write("\n")
 
@@ -1885,20 +1800,15 @@ def save_parameters_to_file(dataset, filename, path=''):
                 output.write(line_fmt % par_tuple + "\n")
             output.write("\n")
 
-    print(" - Saved Best-fit Parameters to file: %s" % (path + filename))
 
-
-def save_cont_parameters_to_file(dataset, filename, path=''):
+def save_cont_parameters_to_file(dataset, filename):
     """Save Chebyshev coefficients to file."""
-    with open(path + filename, 'w') as output:
+    with open(filename, 'w') as output:
         header = "# Chebyshev Polynomial Coefficients"
         output.write(header + "\n")
 
         for reg_num, region in enumerate(dataset.regions):
-            region_header = "# Region %i:  " % reg_num
-            all_lines_string = ", ".join([line.tag for line in region.lines])
-            region_header += all_lines_string + "\n"
-            output.write(region_header)
+            output.write("# Region %i: \n" % reg_num)
             cheb_parnames = list()
             # Find Chebyshev parameters for this region:
             # They are named like 'R0_cheb_p0, R0_cheb_p1, R1_cheb_p0, etc...'
@@ -1914,7 +1824,6 @@ def save_cont_parameters_to_file(dataset, filename, path=''):
                 line = " p%-2i  =  %.3e    %.3e" % (i, coeff.value, coeff.stderr)
                 output.write(line + "\n")
             output.write("\n")
-    print(" - Saved Best-fit Chebyshev Coefficients to file: %s" % (path + filename))
 
 
 def save_fit_regions(dataset, filename, individual=False, path=''):
@@ -1962,9 +1871,9 @@ def save_fit_regions(dataset, filename, individual=False, path=''):
             wl, flux, err, mask = region.unpack()
             nsub = region.kernel_nsub
             if dataset.best_fit and region.has_active_lines():
-                p_obs = voigt.evaluate_profile(wl, dataset.best_fit,
-                                               dataset.lines.values(), region.kernel,
-                                               z_sys=dataset.redshift, kernel_nsub=nsub)
+                p_obs = voigt.evaluate_profile(wl, dataset.best_fit, dataset.redshift,
+                                               dataset.lines.values(), dataset.components,
+                                               region.kernel, kernel_nsub=nsub)
             else:
                 p_obs = np.ones_like(wl)
             data_table = np.column_stack([wl, flux, err, p_obs, mask])
@@ -1993,9 +1902,9 @@ def save_fit_regions(dataset, filename, individual=False, path=''):
             wl, flux, err, mask = region.unpack()
             nsub = region.kernel_nsub
             if dataset.best_fit and region.has_active_lines():
-                p_obs = voigt.evaluate_profile(wl, dataset.best_fit,
-                                               dataset.lines.values(), region.kernel,
-                                               z_sys=dataset.redshift, kernel_nsub=nsub)
+                p_obs = voigt.evaluate_profile(wl, dataset.best_fit, dataset.redshift,
+                                               dataset.lines.values(), dataset.components,
+                                               region.kernel, kernel_nsub=nsub)
             else:
                 p_obs = np.ones_like(wl)
             l_tot.append(wl)
@@ -2019,7 +1928,6 @@ def save_fit_regions(dataset, filename, individual=False, path=''):
             out_file.write("# column 4 : Best-fit profile\n")
             out_file.write("# column 5 : Pixel mask, 1=included, 0=excluded\n")
             np.savetxt(out_file, data_table, fmt="%.3f   %.4f   %.4f   %.4f   %i")
-    print(" - Saved Data for Fit Regions (data + best-fit profile) to file: %s" % (filename))
 
 
 def save_individual_components(dataset, filename, path=''):
@@ -2135,48 +2043,12 @@ def save_individual_components(dataset, filename, path=''):
         with open(filename, 'w') as output:
             output.write(header+'\n')
             np.savetxt(output, data, fmt=data_fmt)
-        print(" - Saved Best-fit Individual Components to file: %s" % (filename))
 
     else:
         print(" [ERROR] - No fit parameters found! \n")
         return
 
 
-def save_EW(EW_list, filename, path=''):
-    """
-    Save the equivalent width data for each line in the input list.
-
-    Parameters
-    ----------
-    EW_list : list[`namedtuple` (EquivalentWidth)]
-        A list of `namedtuple` (EquivalentWidth), see implementation in `VoigtFit.dataset.py`
-
-    filename : str
-        Filename to be used. If the filename already exists, it will be overwritten.
-
-    path : str   [default = '']
-        Specify a path to prepend to the filename in order to save output to a given
-        directory or path. Can be given both as relative or absolute path.
-        If the directory does not exist, it will be created.
-        The final filename will be:
-
-            `path/` + `filename`
-    """
-    header = "# {sigma:.1f}-sigma upper limits listed as u.limit\n".format(**EW_list[0]._asdict())
-    header += "# logN in units of cm^-2, W_rest in units of Å\n"
-    header += "Line           u.limit  logN   logN_err   W_rest    W_err \n"
-    fmt = "{line:13}   {logN_limit:.2f}   {logN:.3f}  {logN_err:.3f}    {W_rest:+.2e}  {W_err:.2e}"
-    with open(path + filename, 'w') as output:
-        output.write(header)
-        for EW in EW_list:
-            output.write(fmt.format(**EW._asdict()) + '\n')
-    print(" - Saved Equivalent Width Data to file: %s" % (path + filename))
-
-def format_EW(EW):
-    fmt = "{line:>13}   logN < {logN_limit:.2f}   ({sigma:.1f} sigma)"
-    return fmt.format(**EW._asdict())
-
-
 def show_components(dataset, ion=None):
     """
     Show the defined components for a given `ion`.
